package no.ntnu.idatt1002.demo.data;

import java.util.ArrayList;

/**
 * RevenueOverview is a class for storing and getting
 * information on your total income and expense.
 */
public class ItemOverview {
    ArrayList<Income> income;
    ArrayList<Expense> expense;

    /**
     * The class constructor.
     */
    public ItemOverview(){
        this.income = new ArrayList<>();   //ArrayList for storing income
        this.expense = new ArrayList<>();   //ArrayList for storing expense
    }

    /**
     * Get an ArrayList of every income.
     * @return   Income ArrayList.
     */
    public ArrayList<Income> getIncome() {
        return income;
    }

    /**
     * Get an ArrayList of every expense.
     * @return   Expense ArrayList.
     */
    public ArrayList<Expense> getExpense() {
        return expense;
    }

    /**
     * Add an Income object to income.
     * @param newIncome   The Income you want to add.
     */
    public void addIncome(Income newIncome){
        if(income.contains(newIncome)){
            throw new IllegalArgumentException("This income is already registered");
        }
        income.add(newIncome);
    }

    /**
     * Add an Expense object to income.
     * @param newExpense   The Expense you want to add.
     */
    public void addExpense(Expense newExpense){
        if(expense.contains(newExpense)){
            throw new IllegalArgumentException("This expense is already registered");
        }
        expense.add(newExpense);
    }

    /**
     * Get the sum of all Income in income.
     * @return   Sum of all Income.
     */
    public double getTotalIncome(){
        return income.stream().map(Item::getAmount).mapToDouble(Double::doubleValue).sum();
    }

    /**
     * Get the sum of all Expense in expense.
     * @return   Sum of all Expense.
     */
    public double getTotalExpense(){
        return expense.stream().map(Item::getAmount).mapToDouble(Double::doubleValue).sum();
    }
}
